==> nextcloud-app-tasks-0.9.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/is.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Verk",
    "Due yesterday" : "Átti að ljúka í gær",
    "Due today" : "Á að ljúka í dag",
    "Due tomorrow" : "Á að ljúka á morgun",
    "Due on" : "Á að ljúka þann",
    "Started yesterday" : "Byrjaði í gær",
    "Starts today" : "Byrjar í dag",
    "Starts tomorrow" : "Byrjar á morgun",
    "Started on" : "Byrjaði þann",
    "Starts on" : "Byrjar þann",
    "[Remind me yesterday at ]HH:mm" : "[Minna mig á í gær klukkan ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Minna mig á í dag klukkan ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Minna mig á á morgun klukkan ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Minna mig á þann ]DD. MMM, YYYY,[ klukkan ]HH:mm",
    "Yesterday" : "Í gær",
    "Today" : "Í dag",
    "Tomorrow" : "Á morgun",
    "in %s" : "í %s",
    "%s ago" : "fyrir %s síðan",
    "seconds" : "sekúndum",
    "a minute" : "mínútu",
    "%d minutes" : "%d mínútum",
    "an hour" : "klukkustund",
    "%d hours" : "%d klukkustundum",
    "a day" : "degi",
    "%d days" : "%d dögum",
    "a month" : "mánuði",
    "%d months" : "%d mánuðum",
    "a year" : "ári",
    "%d years" : "%d árum",
    "week" : "vika",
    "weeks" : "vikur",
    "day" : "dagur",
    "days" : "dagar",
    "hour" : "klukkustund",
    "hours" : "klukkustundir",
    "minute" : "mínúta",
    "minutes" : "mínútur",
    "second" : "sekúnda",
    "before beginning" : "fyrir upphaf",
    "after beginning" : "eftir upphaf",
    "before end" : "fyrir endi",
    "after end" : "eftir endi",
    "Comment" : "Athugasemd",
    "Add a comment" : "Bæta við athugasemd",
    "This will delete the Calendar \"%s\" and all of its entries." : "Þetta mun eyða dagatalinu \"%s\" og öllum færslum þess",
    "The name \"%s\" is already used." : "Nafnið \"%s\" er þegar í notkun.",
    "An empty name is not allowed." : "Autt heiti er ekki leyft.",
    "Hidden" : "Falið",
    "Visible" : "Sýnilegt",
    "Automatic" : "Sjálfvirkt",
    "Sunday" : "Sunnudagur",
    "Monday" : "Mánudagur",
    "Tuesday" : "Þriðjudagur",
    "Wednesday" : "Miðvikudagur",
    "Thursday" : "Fimmtudagur",
    "Friday" : "Föstudagur",
    "Saturday" : "Laugardagur",
    "Add an important item in \"%s\"..." : "Bæta mikilvægu atriði við \"%s\"...",
    "Add an item due today in \"%s\"..." : "Bæta atriði sem á að klárast í dag við \"%s\"...",
    "Add an item in \"%s\"..." : "Bæta atriði við \"%s\"...",
    "Add a current item in \"%s\"..." : "Bæta þessu atriði við \"%s\"...",
    "Add a subtask to \"%s\"..." : "Bæta undirverkefni við \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lokið verk","%n lokin verk"],
    "Hours" : "klukkustundir",
    "Minutes" : "mínútur",
    "Set due date" : "Setja skiladag",
    "%s %% completed" : "%s %% lokið",
    "priority %s: " : "forgangur %s: ",
    "high" : "mikill",
    "medium" : "miðlungs",
    "low" : "lítill",
    "no priority assigned" : "Enginn forgangur settur",
    "Remind me" : "Áminna mig",
    "at the end" : "við lok",
    "at the beginning" : "við upphaf",
    "Set start date" : "Setja upphafsdag",
    "{calendar} shared by {owner}" : "{calendar} deilt af {owner}",
    "Unnamed" : "Nafnlaust",
    "Important" : "Mikilvægt",
    "Week" : "Vika",
    "All" : "Allt",
    "Current" : "Núverandi",
    "Completed" : "Lokið",
    "The Tasks app for Nextcloud" : "Verkefnaforrit fyrir Nextcloud",
    "Delete" : "Eyða",
    "Cancel" : "Hætta við",
    "Edit" : "Breyta",
    "Link" : "Tengill",
    "Download" : "Sækja",
    "Save" : "Vista",
    "Add List..." : "Bæta við lista...",
    "New List" : "Nýr listi",
    "Settings" : "Stillingar",
    "Start of week" : "Upphaf viku",
    "Visibility of Smart Collections" : "Sýnileiki snjallsafna (Smart Collections)",
    "Change sort order" : "Breyta röðun",
    "Default" : "Sjálfgefið",
    "Due date" : "Skiladagur",
    "Start date" : "Upphafsdagur",
    "Priority" : "Forgangur",
    "Alphabetically" : "Í stafrófsröð",
    "Manually" : "Handvirkt",
    "Load remaining completed tasks." : "Hlaða inn afgangnum af loknum verkum.",
    "Task is completed" : "Verki er lokið",
    "All day" : "Heilsdagsviðburður",
    "(New category)" : "(nýr flokkur)",
    "Select categories..." : "Veldu flokka...",
    "Loading the task..." : "Hleð inn verkinu...",
    "Task not found!" : "Verk fannst ekki!",
    "add a subtask to" : "bæta undirverkefni við",
    "Toggle subtasks" : "Víxla undirverkum af/á",
    "Toggle completed subtasks" : "Víxla sýnileika kláraðra undirverka"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-app-tasks-0.9.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/is.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Verk",
    "Due yesterday" : "Átti að ljúka í gær",
    "Due today" : "Á að ljúka í dag",
    "Due tomorrow" : "Á að ljúka á morgun",
    "Due on" : "Á að ljúka þann",
    "Started yesterday" : "Byrjaði í gær",
    "Starts today" : "Byrjar í dag",
    "Starts tomorrow" : "Byrjar á morgun",
    "Started on" : "Byrjaði þann",
    "Starts on" : "Byrjar þann",
    "[Remind me yesterday at ]HH:mm" : "[Minna mig á í gær klukkan ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Minna mig á í dag klukkan ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Minna mig á á morgun klukkan ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Minna mig á þann ]DD. MMM, YYYY,[ klukkan ]HH:mm",
    "Yesterday" : "Í gær",
    "Today" : "Í dag",
    "Tomorrow" : "Á morgun",
    "in %s" : "í %s",
    "%s ago" : "fyrir %s síðan",
    "seconds" : "sekúndum",
    "a minute" : "mínútu",
    "%d minutes" : "%d mínútum",
    "an hour" : "klukkustund",
    "%d hours" : "%d klukkustundum",
    "a day" : "degi",
    "%d days" : "%d dögum",
    "a month" : "mánuði",
    "%d months" : "%d mánuðum",
    "a year" : "ári",
    "%d years" : "%d árum",
    "week" : "vika",
    "weeks" : "vikur",
    "day" : "dagur",
    "days" : "dagar",
    "hour" : "klukkustund",
    "hours" : "klukkustundir",
    "minute" : "mínúta",
    "minutes" : "mínútur",
    "second" : "sekúnda",
    "before beginning" : "fyrir upphaf",
    "after beginning" : "eftir upphaf",
    "before end" : "fyrir endi",
    "after end" : "eftir endi",
    "Comment" : "Athugasemd",
    "Add a comment" : "Bæta við athugasemd",
    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "Þetta mun eyða dagatalinu \"%s\" og öllum færslum þess.",
    "The name \"%s\" is already used." : "Nafnið \"%s\" er þegar í notkun.",
    "An empty name is not allowed." : "Autt heiti er ekki leyft.",
    "Hidden" : "Falið",
    "Visible" : "Sýnilegt",
    "Automatic" : "Sjálfvirkt",
    "Sunday" : "Sunnudagur",
    "Monday" : "Mánudagur",
    "Tuesday" : "Þriðjudagur",
    "Wednesday" : "Miðvikudagur",
    "Thursday" : "Fimmtudagur",
    "Friday" : "Föstudagur",
    "Saturday" : "Laugardagur",
    "Add an important item in \"%s\"..." : "Bæta mikilvægu atriði við \"%s\"...",
    "Add an item due today in \"%s\"..." : "Bæta atriði sem á að klárast í dag við \"%s\"...",
    "Add an item in \"%s\"..." : "Bæta atriði við \"%s\"...",
    "Add a current item in \"%s\"..." : "Bæta þessu atriði við \"%s\"...",
    "Add a subtask to \"%s\"..." : "Bæta undirverkefni við \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lokið verk","%n lokin verk"],
    "Hours" : "klukkustundir",
    "Minutes" : "mínútur",
    "Set due date" : "Setja skiladag",
    "%s %% completed" : "%s %% lokið",
    "priority %s: " : "forgangur %s: ",
    "high" : "mikill",
    "medium" : "miðlungs",
    "low" : "lítill",
    "no priority assigned" : "Enginn forgangur settur",
    "Remind me" : "Áminna mig",
    "at the end" : "við lok",
    "at the beginning" : "við upphaf",
    "Set start date" : "Setja upphafsdag",
    "{calendar} shared by {owner}" : "{calendar} deilt af {owner}",
    "Unnamed" : "Nafnlaust",
    "Important" : "Mikilvægt",
    "Week" : "Vika",
    "All" : "Allt",
    "Current" : "Núverandi",
    "Completed" : "Lokið",
    "The Tasks app for Nextcloud" : "Verkefnaforrit fyrir Nextcloud",
    "Delete" : "Eyða",
    "Cancel" : "Hætta við",
    "Edit" : "Breyta",
    "Link" : "Tengill",
    "Download" : "Sækja",
    "Save" : "Vista",
    "Add List..." : "Bæta við lista...",
    "New List" : "Nýr listi",
    "Settings" : "Stillingar",
    "Start of week" : "Upphaf viku",
    "Visibility of Smart Collections" : "Sýnileiki snjallsafna (Smart Collections)",
    "Change sort order" : "Breyta röðun",
    "Default" : "Sjálfgefið",
    "Due date" : "Skiladagur",
    "Start date" : "Upphafsdagur",
    "Priority" : "Forgangur",
    "Alphabetically" : "Í stafrófsröð",
    "Manually" : "Handvirkt",
    "Load remaining completed tasks." : "Hlaða inn afgangnum af loknum verkum.",
    "Task is completed" : "Verki er lokið",
    "All day" : "Heilsdagsviðburður",
    "(New category)" : "(nýr flokkur)",
    "Select categories..." : "Veldu flokka...",
    "Loading the task..." : "Hleð inn verkinu...",
    "Task not found!" : "Verk fannst ekki!",
    "add a subtask to" : "bæta undirverkefni við",
    "Toggle subtasks" : "Víxla undirverkum af/á",
    "Toggle completed subtasks" : "Víxla sýnileika kláraðra undirverka"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
